@@ -15,4 +15,7 @@ API_RESPONSE_STATUS_INVALID = "invalid_action_name"
 
 #Request base params keys
 REQUEST_CHANNEL_KEY = "channel"
-REQUEST_STATE_KEY = "state"
\ No newline at end of file
+REQUEST_STATE_KEY = "state"
+
+#Logger lib name
+LOGGER_NAME = "foxrestapiclient_log"
\ No newline at end of file
