@@ -89,7 +89,7 @@ class FoxBaseDevice:
         """Return channel name or name."""
         if (self.device_info_data is None or (channel < 1 and channel > 2)):
             return self.name
-        if len(self.device_info_data.device_channels_name) > 1:
+        if len(self.device_info_data.device_channels_name) >= 1:
             return self.device_info_data.device_channels_name[channel-1]
         return self.name
 
