@@ -18,8 +18,7 @@ class FoxRGBWDevice(FoxBaseDevice):
 
     def __init__(self, device_data: DeviceData):
         """Initalize object."""
-        super().__init__(device_data.name, device_data.host, device_data.api_key,
-                        device_data.mac_addr, device_data.type)
+        super().__init__(device_data)
         self.hsv_color = [0, 0, 0]
         self.__device_api_client = self.DeviceRestApiImplementer(self._rest_api_client)
         self._state = False
